//
// Copyright 2014 Perforce Software Inc.
//

using Perforce.Helper;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Perforce.ViewModel {
    public class HelperApplicationUtilityViewModel : ViewModelBase {

        private ObservableCollection<Mapping> _mappings;

        public HelperApplicationUtilityViewModel() {
            var helper = Utility.GetExtensionHelper();
            var currentMappings = helper.Mappings;
            _mappings = new ObservableCollection<Mapping>();
            foreach (var key in currentMappings.Keys) {
                _mappings.Add(new Mapping { Extension = key, Application = currentMappings[key] }); 
            }
        }

        public ObservableCollection<Mapping> Mappings {
            get {
                return _mappings;
            }
            set {
                Console.WriteLine("#### calling setter on mappings");
                _mappings = value;
            }
        }

        public void UpdateMapping(int row, string appPath) {
            if (row < _mappings.Count) {
                _mappings[row].Application = appPath;
            }
            OnPropertyChanged("Mappings");
        }

        public void RemoveRow(int row) {
            if (row < _mappings.Count) {
                _mappings.RemoveAt(row);
                OnPropertyChanged("Mappings");
            }

        }
    }

    public class Mapping {
        public string Extension { get; set; }
        public string Application { get; set; }

        public override string ToString() {
            return string.Format("{0}:{1}", Extension, Application);
        }
    }
}
